aboutsummaryrefslogtreecommitdiffstats
path: root/net/batman-adv/types.h
diff options
context:
space:
mode:
authorSimon Wunderlich <sw@simonwunderlich.de>2015-08-08 02:01:50 +0200
committerAntonio Quartulli <a@unstable.cc>2015-12-16 00:21:42 +0800
commit18165f6f6570318ad0bb1e60c2ae597cdfd09a50 (patch)
treea4f2b1961369488044e80d5bfbbb90c63a350fbc /net/batman-adv/types.h
parentbatman-adv: update last seen field of single hop originators (diff)
downloadlinux-dev-18165f6f6570318ad0bb1e60c2ae597cdfd09a50.tar.xz
linux-dev-18165f6f6570318ad0bb1e60c2ae597cdfd09a50.zip
batman-adv: rename equiv/equal or better to similar or better
Since the function applies a threshold and also slightly worse values are accepted, ''equal or better'' does not represent the intention of the function. ''Similar or better'' represents that better. Signed-off-by: Simon Wunderlich <sw@simonwunderlich.de> Signed-off-by: Marek Lindner <mareklindner@neomailbox.ch> Signed-off-by: Antonio Quartulli <antonio@meshcoding.com>
Diffstat (limited to 'net/batman-adv/types.h')
-rw-r--r--net/batman-adv/types.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/net/batman-adv/types.h b/net/batman-adv/types.h
index 815c960d31b4..9bdb21c2368a 100644
--- a/net/batman-adv/types.h
+++ b/net/batman-adv/types.h
@@ -1156,8 +1156,8 @@ struct batadv_forw_packet {
* @bat_hardif_neigh_init: called on creation of single hop entry
* @bat_neigh_cmp: compare the metrics of two neighbors for their respective
* outgoing interfaces
* @bat_neigh_is_equiv_or_better: check if neigh1 is equally good or better
* than neigh2 for their respective outgoing interface from the metric
* prospective
* @bat_neigh_print: print the single hop neighbor list (optional)
* @bat_neigh_free: free the resources allocated by the routing algorithm for a
@@ -1185,7 +1185,7 @@ struct batadv_algo_ops {
struct batadv_hard_iface *if_outgoing1,
struct batadv_neigh_node *neigh2,
struct batadv_hard_iface *if_outgoing2);
- bool (*bat_neigh_is_equiv_or_better)
+ bool (*bat_neigh_is_similar_or_better)
(struct batadv_neigh_node *neigh1,
struct batadv_hard_iface *if_outgoing1,
struct batadv_neigh_node *neigh2,
@@ -1156,8 +1156,8 @@ struct batadv_forw_packet {
* @bat_neigh_cmp: compare the metrics of two neighbors for their respective
* outgoing interfaces
- * @bat_neigh_is_equiv_or_better: check if neigh1 is equally good or better
- * than neigh2 for their respective outgoing interface from the metric
+ * @bat_neigh_is_similar_or_better: check if neigh1 is equally similar or
+ * better than neigh2 for their respective outgoing interface from the metric
* prospective
* @bat_neigh_print: print the single hop neighbor list (optional)